/* $Id: sm_mem.c,v 1.3 2005/10/18 19:58:12 dijkstra Exp $ */

#include <stdlib.h>

#include "sylimits.h"
#include "data.h"
#include "error.h"

void
init_mem(struct stream *st)
{
    fatal("mem module not available");
}
void
gets_mem()
{
    fatal("mem module not available");
}
int
get_mem(char *symon_buf, int maxlen, struct stream *st)
{
    fatal("mem module not available");

    /* NOT REACHED */
    return 0;
}
